==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DeploymentCauseFluentImpl<A extends io.fabric8.openshift.api.model.DeploymentCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DeploymentCauseFluent<A>{
  public DeploymentCauseFluentImpl() {
  }
  public DeploymentCauseFluentImpl(io.fabric8.openshift.api.model.DeploymentCause instance) {
    this.withImageTrigger(instance.getImageTrigger()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder imageTrigger;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildImageTrigger instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DeploymentCauseImageTrigger getImageTrigger() {
    return this.imageTrigger!=null?this.imageTrigger.build():null;
  }
  public io.fabric8.openshift.api.model.DeploymentCauseImageTrigger buildImageTrigger() {
    return this.imageTrigger!=null?this.imageTrigger.build():null;
  }
  public A withImageTrigger(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger imageTrigger) {
    _visitables.get("imageTrigger").remove(this.imageTrigger);
    if (imageTrigger!=null){ this.imageTrigger= new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder(imageTrigger); _visitables.get("imageTrigger").add(this.imageTrigger);} return (A) this;
  }
  public java.lang.Boolean hasImageTrigger() {
    return this.imageTrigger != null;
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> withNewImageTrigger() {
    return new io.fabric8.openshift.api.model.DeploymentCauseFluentImpl.ImageTriggerNestedImpl();
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> withNewImageTriggerLike(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger item) {
    return new io.fabric8.openshift.api.model.DeploymentCauseFluentImpl.ImageTriggerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> editImageTrigger() {
    return withNewImageTriggerLike(getImageTrigger());
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> editOrNewImageTrigger() {
    return withNewImageTriggerLike(getImageTrigger() != null ? getImageTrigger(): new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder().build());
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> editOrNewImageTriggerLike(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger item) {
    return withNewImageTriggerLike(getImageTrigger() != null ? getImageTrigger(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeploymentCauseFluentImpl that = (DeploymentCauseFluentImpl) o;
    if (imageTrigger != null ? !imageTrigger.equals(that.imageTrigger) :that.imageTrigger != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageTrigger,  type,  additionalProperties,  super.hashCode());
  }
  public class ImageTriggerNestedImpl<N> extends io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluentImpl<io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<N>> implements io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImageTriggerNestedImpl(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger item) {
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder(this, item);
    }
    ImageTriggerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder(this);
    }
    io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder builder;
    public N and() {
      return (N) DeploymentCauseFluentImpl.this.withImageTrigger(builder.build());
    }
    public N endImageTrigger() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.3-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class DeploymentCauseFluentImpl<A extends io.fabric8.openshift.api.model.DeploymentCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.DeploymentCauseFluent<A>{
  public DeploymentCauseFluentImpl() {
  }
  public DeploymentCauseFluentImpl(io.fabric8.openshift.api.model.DeploymentCause instance) {
    this.withImageTrigger(instance.getImageTrigger()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder imageTrigger;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildImageTrigger instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.DeploymentCauseImageTrigger getImageTrigger() {
    return this.imageTrigger!=null?this.imageTrigger.build():null;
  }
  public io.fabric8.openshift.api.model.DeploymentCauseImageTrigger buildImageTrigger() {
    return this.imageTrigger!=null?this.imageTrigger.build():null;
  }
  public A withImageTrigger(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger imageTrigger) {
    _visitables.get("imageTrigger").remove(this.imageTrigger);
    if (imageTrigger!=null){ this.imageTrigger= new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder(imageTrigger); _visitables.get("imageTrigger").add(this.imageTrigger);} return (A) this;
  }
  public java.lang.Boolean hasImageTrigger() {
    return this.imageTrigger != null;
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> withNewImageTrigger() {
    return new io.fabric8.openshift.api.model.DeploymentCauseFluentImpl.ImageTriggerNestedImpl();
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> withNewImageTriggerLike(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger item) {
    return new io.fabric8.openshift.api.model.DeploymentCauseFluentImpl.ImageTriggerNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> editImageTrigger() {
    return withNewImageTriggerLike(getImageTrigger());
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> editOrNewImageTrigger() {
    return withNewImageTriggerLike(getImageTrigger() != null ? getImageTrigger(): new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder().build());
  }
  public io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<A> editOrNewImageTriggerLike(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger item) {
    return withNewImageTriggerLike(getImageTrigger() != null ? getImageTrigger(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeploymentCauseFluentImpl that = (DeploymentCauseFluentImpl) o;
    if (imageTrigger != null ? !imageTrigger.equals(that.imageTrigger) :that.imageTrigger != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imageTrigger,  type,  additionalProperties,  super.hashCode());
  }
  public class ImageTriggerNestedImpl<N> extends io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluentImpl<io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<N>> implements io.fabric8.openshift.api.model.DeploymentCauseFluent.ImageTriggerNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ImageTriggerNestedImpl(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger item) {
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder(this, item);
    }
    ImageTriggerNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder(this);
    }
    io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder builder;
    public N and() {
      return (N) DeploymentCauseFluentImpl.this.withImageTrigger(builder.build());
    }
    public N endImageTrigger() {
      return and();
    }
    
  }
  
}
